@@ -568,7 +568,9 @@ impl SyntaxError {
             SyntaxError::TS2371 => "A parameter initializer is only allowed in a function or \
                                     constructor implementation"
                 .into(),
-            SyntaxError::TS2406 => "Invalid left-hand side in 'for...in' statement".into(),
+            SyntaxError::TS2406 => "The left-hand side of an assignment expression must be a \
+                                    variable or a property access."
+                .into(),
             SyntaxError::TS2410 => "The 'with' statement is not supported. All symbols in a \
                                     'with' block will have type 'any'."
                 .into(),
