@@ -62,13 +62,11 @@ impl<'a, I: Tokens> Parser<I> {
                     left,
                     op: op!("||"),
                     ..
-                }) => match &**left {
-                    Expr::Bin(BinExpr { op: op!("??"), .. }) => {
+                }) => {
+                    if let Expr::Bin(BinExpr { op: op!("??"), .. }) = &**left {
                         self.emit_err(*span, SyntaxError::NullishCoalescingWithLogicalOp);
                     }
-
-                    _ => {}
-                },
+                }
                 _ => {}
             }
 
@@ -219,7 +217,7 @@ impl<'a, I: Tokens> Parser<I> {
             right,
         }));
 
-        return Ok((node, Some(min_prec)));
+        Ok((node, Some(min_prec)))
     }
 
     /// Parse unary expression and update expression.
@@ -289,9 +287,8 @@ impl<'a, I: Tokens> Parser<I> {
             };
 
             if op == op!("delete") {
-                match *arg {
-                    Expr::Ident(ref i) => self.emit_strict_mode_err(i.span, SyntaxError::TS1102),
-                    _ => {}
+                if let Expr::Ident(ref i) = *arg {
+                    self.emit_strict_mode_err(i.span, SyntaxError::TS1102)
                 }
             }
 
