@@ -1088,6 +1088,7 @@ impl<'a, I: Tokens> Parser<I> {
     }
 }
 
+#[allow(clippy::enum_variant_names)]
 enum ForHead {
     For {
         init: Option<VarDeclOrExpr>,
@@ -1767,7 +1768,7 @@ export default function waitUntil(callback, options = {}) {
                     }]
                 })
             ),
-            _ => assert!(false),
+            _ => unreachable!(),
         }
     }
     #[test]
