@@ -281,6 +281,8 @@ pub(super) trait ExprExt {
 
             Expr::Seq(..) => false,
 
+            Expr::OptChain(..) => false,
+
             // MemberExpression is valid assignment target
             Expr::PrivateName(..) => false,
 
@@ -292,8 +294,7 @@ pub(super) trait ExprExt {
             | Expr::JSXFragment(..) => false,
 
             // typescript
-            Expr::OptChain(OptChainExpr { ref expr, .. })
-            | Expr::TsNonNull(TsNonNullExpr { ref expr, .. })
+            Expr::TsNonNull(TsNonNullExpr { ref expr, .. })
             | Expr::TsTypeAssertion(TsTypeAssertion { ref expr, .. })
             | Expr::TsAs(TsAsExpr { ref expr, .. }) => {
                 expr.is_valid_simple_assignment_target(strict)
